==> haskell-vault-0.3.0.7-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vault
version: 0.3.0.7
id: vault-0.3.0.7-42kzp1yldz83jLl0I1vRZX
key: vault-0.3.0.7-42kzp1yldz83jLl0I1vRZX
license: BSD3
copyright: (c) Heinrich Apfelmus 2011-2013
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
homepage: https://github.com/HeinrichApfelmus/vault
synopsis: a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.
category: Data
author: Heinrich Apfelmus, Elliott Hird
exposed: True
indefinite: False
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict
abi: 7ececdfffdd84dcce6af66eaff4068e0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/vault-0.3.0.7
library-dirs: /usr/lib/ghc-8.2.2/site-local/vault-0.3.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/vault-0.3.0.7
hs-libraries: HSvault-0.3.0.7-42kzp1yldz83jLl0I1vRZX
depends:
    base-4.10.1.0 containers-0.5.10.2
    hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    unordered-containers-0.2.9.0-14GJxyni7Ou4ztgK034uJm
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             unordered-containers-0.2.9.0-14GJxyni7Ou4ztgK034uJm=a19fc431946ec4b21dbc4dc9d0f6448c
haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html: /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vault-0.3.1.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vault
version: 0.3.1.0
id: vault-0.3.1.0-KZjLzpZaXUl2rgXB8vScW
key: vault-0.3.1.0-KZjLzpZaXUl2rgXB8vScW
license: BSD3
copyright: (c) Heinrich Apfelmus 2011-2013
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
homepage: https://github.com/HeinrichApfelmus/vault
synopsis: a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.
category: Data
author: Heinrich Apfelmus, Elliott Hird
exposed: True
indefinite: False
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict
abi: cd0c59686eb1247cdfa4d8b1ab351519
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/vault-0.3.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/vault-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/vault-0.3.1.0
hs-libraries: HSvault-0.3.1.0-KZjLzpZaXUl2rgXB8vScW
depends:
    base-4.10.1.0 containers-0.5.10.2
    hashable-1.2.6.1-A4keFPUppGkCw7JMX4jBTk
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hashable-1.2.6.1-A4keFPUppGkCw7JMX4jBTk=526c49aca960d0292e5723576545a03d
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA=bcd116646f2dca4381cb4b7cc7ba7fb1
haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html: /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
